@@ -69,4 +69,4 @@ def company(cik):
     print('>📦\tfetching company: %s ...'%cik)
     
 def financial_statement(name,kind):
-    print('> 📦\tfetching financial statement: %s for %s ...'%(kind,kind))
+    print('> 📦\tfetching financial statement: %s for %s ...'%(kind,name))
